YAML schema
===========

This is a useful discussion on yaml/json schema including how to enable
schema validated editing of yaml files in vscode.

https://dev.to/brpaz/how-to-create-your-own-auto-completion-for-json-and-yaml-files-on-vs-code-with-the-help-of-json-schema-k1i
